@@ -9,11 +9,12 @@ from binascii import unhexlify
 
 import base58
 import ecdsa
-from eth_keys import KeyAPI
 from eth_account import Account as ETHAccount
-from trx_utils import is_hex, is_bytes
+from eth_keys import KeyAPI
+from trx_utils import is_hex, is_bytes, is_dict
 
 from tronpytool.common.datastructures import AttributeDict
+from tronpytool.common.key import PrivateKey as PFactory
 
 
 class Account:
@@ -21,7 +22,7 @@ class Account:
     def generate_address(self, priv_key=None) -> dict:
         """Generate a random address."""
         if priv_key is None:
-            priv_key = PrivateKey.random()
+            priv_key = PFactory.random()
         return {
             "base58check_address": priv_key.public_key.to_base58check_address(),
             "hex_address": priv_key.public_key.to_hex_address(),
@@ -31,7 +32,7 @@ class Account:
 
     def get_address_from_passphrase(self, passphrase: str) -> dict:
         """Get an address from a passphrase, compatiable with `wallet/createaddress`."""
-        priv_key = PrivateKey.from_passphrase(passphrase.encode())
+        priv_key = PFactory.from_passphrase(passphrase.encode())
         return self.generate_address(priv_key)
 
     @staticmethod
@@ -54,17 +55,16 @@ class Account:
         return ETHAccount.recoverHash(message_hash, signature=signature)
 
 
-class Address(object):
+class Address:
     @staticmethod
-    def from_hex(address):
+    def from_hex(address) -> str:
         """Helper function that will convert a generic value from hex"""
         if not is_hex(address):
             return address
-
-        return base58.b58encode_check(bytes.fromhex(address))
+        return base58.b58encode_check(bytes.fromhex(address)).decode()
 
     @staticmethod
-    def to_hex(address):
+    def to_hex(address) -> str:
         """Helper function that will convert a generic value to hex"""
         if is_hex(address):
             return address.lower().replace('0x', '41', 2)
@@ -72,18 +72,49 @@ class Address(object):
         return base58.b58decode_check(address).hex().upper()
 
     @staticmethod
-    def from_private_key(private_key):
+    def to_hexv2(address: any) -> str:
+        """Helper function that will convert a generic value (TRON ADDRESS) to hex"""
+
+        if is_dict(address):
+            addressp = ''
+            if hasattr(address, 'hex'):
+                addressp = address.hex
+
+            if hasattr(address, 'Hex'):
+                addressp = address.Hex
+
+            print(addressp)
+
+            if is_hex(addressp):
+                return addressp.lower().replace('0x', '41', 2)
+            else:
+                return base58.b58decode_check(addressp).hex().upper()
+        elif type(address) is str:
+            if is_hex(address):
+                return address.lower().replace('0x', '41', 2)
+            else:
+                return base58.b58decode_check(address).hex().upper()
+        else:
+            raise KeyError(
+                "is this not a proper address type, please look for the good one but found item {}".format(address))
+
+    @staticmethod
+    def from_private_key(private_key) -> AttributeDict:
         return PrivateKey(private_key).address
 
 
 class PrivateKey(object):
-    def __init__(self, private_key):
+
+    def __init__(self, private_key: str):
         """Work with private key.
         Getting: PublicKey, PublicToAddress
 
         Example:::
             PrivateKey("4d1bc37b069b9f2e975c37770b7c87185dc3a10454e3ea024ce1fce8f3eb78bf")
         """
+        if private_key is None:
+            raise ValueError('Empty private key here')
+
         _private = unhexlify(bytes(private_key, encoding='utf8'))
         self._key = KeyAPI.PrivateKey(_private)
         _length = len(self._key)
@@ -93,7 +124,7 @@ class PrivateKey(object):
             raise ValueError('Key length must not exceed 64 length')
 
     @property
-    def private_key(self):
+    def private_key(self) -> str:
         _raw_key = self._key.to_bytes()
         return codecs.decode(codecs.encode(_raw_key, 'hex'), 'ascii')
 
@@ -103,7 +134,7 @@ class PrivateKey(object):
         return '04' + str(public_key)[2:]
 
     @property
-    def address(self):
+    def address(self) -> AttributeDict:
         public_key = self._key.public_key
         address = '41' + public_key.to_address()[2:]
         to_base58 = base58.b58encode_check(bytes.fromhex(address))
