@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # --------------------------------------------------------------------
 # Copyright (c) iEXBase. All rights reserved.
 # Licensed under the MIT License.
@@ -13,7 +14,6 @@ DEFAULT_NODES = {
     'event_server': 'https://api.trongrid.io'
 }
 
-
 CONF_MAINNET = {
     "full_node": "https://api.trongrid.io",
     "event_server": "https://api.trongrid.io",
@@ -45,7 +45,7 @@ ALL = {
     "mainnet": CONF_MAINNET,
     "nile": CONF_NILE,
     "shasta": CONF_SHASTA,
-    "tronex": CONF_TRONEX,
+    "tronex": CONF_TRONEX
 }
 
 
