@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # --------------------------------------------------------------------
 # Copyright (c) iEXBase. All rights reserved.
 # Licensed under the MIT License.
@@ -20,12 +21,12 @@ from trx_utils import (
     encode_hex
 )
 
+from tronpytool.common.validation import is_valid_url
 from tronpytool.exceptions import (
     InvalidTronError,
     TronError,
     InvalidAddress
 )
-from tronpytool.common.validation import is_valid_url
 
 DEFAULT_TIME = datetime.now()
 START_DATE = int(DEFAULT_TIME.timestamp() * 1000)
@@ -502,10 +503,10 @@ class TransactionBuilder(object):
         transaction = dict(**kwargs)
         transaction.setdefault('owner_address', self.tron.address.to_hex(owner_address))
 
-        return self.tron.manager.request('/wallet/deploycontract',
-                                         transaction)
+        return self.tron.manager.request('/wallet/deploycontract', transaction)
 
     def trigger_smart_contract(self, **kwargs):
+        print(kwargs)
         """Trigger Smart Contract
         Calls a function on a contract
 
@@ -521,9 +522,7 @@ class TransactionBuilder(object):
             >>>     call_value=0,
             >>>     parameters=[
             >>>        {'type': 'int256', 'value': 1},
-            >>>        {'type': 'int256', 'value': 1}
-    ]
-)
+            >>>        {'type': 'int256', 'value': 1}])
 
         Returns:
             TransactionExtention, TransactionExtention contains unsigned Transaction
@@ -556,6 +555,7 @@ class TransactionBuilder(object):
         if not is_integer(fee_limit) or fee_limit <= 0 or fee_limit > 1000000000:
             raise ValueError('Invalid fee limit provided')
 
+        """remove all the spaces"""
         function_selector = function_selector.replace('/\s*/g', '')
 
         if len(parameters) > 0:
